import request from '@/utils/request'

// 查询车辆类型列表
export function listVehicle_type(query) {
  return request({
    url: '/system/vehicle_type/list',
    method: 'get',
    params: query
  })
}

// 查询车辆类型详细
export function getVehicle_type(typeId) {
  return request({
    url: '/system/vehicle_type/' + typeId,
    method: 'get'
  })
}

// 新增车辆类型
export function addVehicle_type(data) {
  return request({
    url: '/system/vehicle_type',
    method: 'post',
    data: data
  })
}

// 修改车辆类型
export function updateVehicle_type(data) {
  return request({
    url: '/system/vehicle_type',
    method: 'put',
    data: data
  })
}

// 删除车辆类型
export function delVehicle_type(typeId) {
  return request({
    url: '/system/vehicle_type/' + typeId,
    method: 'delete'
  })
}
